@@ -1,6 +1,6 @@
 // This may look like C code, but it's really -*- C++ -*-
 /*
- * Copyright (C) 2008 Emweb bvba, Kessel-Lo, Belgium.
+ * Copyright (C) 2008 Emweb bv, Herent, Belgium.
  *
  * See the LICENSE file for terms of use.
  */
@@ -9,20 +9,29 @@
 
 #include <Wt/WFlags.h>
 #include <Wt/Core/observing_ptr.hpp>
+
 #include <memory>
 
 /*! \file */
 
 namespace Wt {
 
-  /* Since we target C++11, we're sorely missing std::make_unique */
+  /* make_unique implementation for backwards compatibility for Wt versions before 4.5.0 */
   namespace cpp14 {
 #ifndef WT_TARGET_JAVA
+#ifdef WT_CXX14
+    template<typename T, typename ...Args>
+    auto make_unique(Args&& ...args) -> decltype(std::make_unique<T, Args...>(std::forward<Args>(args)...))
+    {
+      return std::make_unique<T, Args...>(std::forward<Args>(args)...);
+    }
+#else // WT_CXX14
     template<typename T, typename ...Args>
     std::unique_ptr<T> make_unique( Args&& ...args )
     {
       return std::unique_ptr<T>(new T(std::forward<Args>(args)...));
     }
+#endif // WT_CXX14
 #else // WT_TARGET_JAVA
     template<typename T>
     std::unique_ptr<T> make_unique();
@@ -247,6 +256,17 @@ namespace Wt {
       template <class UserType> class AuthInfo;
       template <class DboType> class UserDatabase;
     }
+
+#ifdef WT_HAS_SAML
+    namespace Saml {
+      struct Assertion;
+      struct Attribute;
+      class Process;
+      class Service;
+      struct Subject;
+      class Widget;
+    }
+#endif // WT_HAS_SAML
   }
 
   namespace Chart {
@@ -430,7 +450,7 @@ enum class Side {
 
 W_DECLARE_OPERATORS_FOR_FLAGS(Side)
 
-static const WFlags<Side> AllSides = 
+static const WFlags<Side> AllSides =
   Side::Left | Side::Right | Side::Top | Side::Bottom;
 
 /*! \brief Enumeration that specifies a horizontal or a vertical alignment.
@@ -505,13 +525,13 @@ W_DECLARE_OPERATORS_FOR_FLAGS(AlignmentFlag)
 
 /*! \brief Combination of all horizontal alignment flags */
 static const WFlags<AlignmentFlag> AlignHorizontalMask
-= AlignmentFlag::Left | AlignmentFlag::Right | 
+= AlignmentFlag::Left | AlignmentFlag::Right |
   AlignmentFlag::Center | AlignmentFlag::Justify;
 
 /*! \brief Combination of all vertical alignment flags */
 static const WFlags<AlignmentFlag> AlignVerticalMask
-= AlignmentFlag::Baseline | AlignmentFlag::Sub | 
-  AlignmentFlag::Super | AlignmentFlag::Top | 
+= AlignmentFlag::Baseline | AlignmentFlag::Sub |
+  AlignmentFlag::Super | AlignmentFlag::Top |
   AlignmentFlag::TextTop | AlignmentFlag::Middle |
   AlignmentFlag::Bottom | AlignmentFlag::TextBottom;
 
@@ -974,7 +994,7 @@ enum class MatchFlag {
 W_DECLARE_OPERATORS_FOR_FLAGS(MatchFlag)
 
 /*! \brief Type part of MatchFlags */
-static const WFlags<MatchFlag> MatchTypeMask = 
+static const WFlags<MatchFlag> MatchTypeMask =
   MatchFlag::Exactly | MatchFlag::StringExactly |
   MatchFlag::StartsWith | MatchFlag::EndsWith |
   MatchFlag::RegExp | MatchFlag::WildCard;
@@ -1028,7 +1048,7 @@ W_DECLARE_OPERATORS_FOR_FLAGS(HeaderFlag)
  */
 enum class MetaHeaderType {
   Meta,       //!< Of the form &lt;meta name=... content=... &gt;
-  Property,   //!< Of the form &lt;meta property=... content=... &gt; 
+  Property,   //!< Of the form &lt;meta property=... content=... &gt;
   HttpHeader  //!< Of the form &lt;meta http-equiv=... content=... &gt;
 };
 
@@ -1091,6 +1111,12 @@ enum class RegExpFlag {
 W_DECLARE_OPERATORS_FOR_FLAGS(RegExpFlag)
 #endif // WT_TARGET_JAVA
 
+#ifdef WT_TARGET_JAVA
+struct AutoCloseable {
+  virtual void close() = 0;
+};
+#endif // WT_TARGET_JAVA
+
 }
 
 #endif // WGLOBALS_H_
